@@ -25,10 +25,10 @@ public:
     explicit MainWindow(const QUrl& url);
 protected:
     void setupActions();
-private slots:
+private Q_SLOTS:
     void startingGame();
     void welcomeScreen();
-    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *event) override;
 };
 
 #endif // MAINWINDOW_H
