@@ -11,46 +11,47 @@
 #ifndef NETWORKDIALOG_H
 #define NETWORKDIALOG_H
 
-#include <KDialog>
+#include <QDialog>
+#include <QUrl>
 
 class KComboBox;
-class KIntSpinBox;
+class KPluralHandlingSpinBox;
 class KLineEdit;
 class QLabel;
 class QTcpSocket;
-namespace DNSSD { class PublicService; }
+class QPushButton;
+namespace KDNSSD { class PublicService; }
 
-class NetworkDialog : public KDialog
+class NetworkDialog : public QDialog
 {
 Q_OBJECT
+    QPushButton *m_okButton;
     KLineEdit* m_nickname;
     KLineEdit* m_hostname;
     QTcpSocket* m_socket;
-    KIntSpinBox* m_port;
+    KPluralHandlingSpinBox* m_port;
     QLabel* m_feedback;
     KComboBox* m_games;
-    DNSSD::PublicService* m_publisher;
+    KDNSSD::PublicService* m_publisher;
     bool m_client;
     
     QString hostname() const;
     int port() const;
-private slots:
+private Q_SLOTS:
     void savePreferences();
     
     void clientOK();
     void clientError();
     void serverOK();
     void serviceSelected(int idx);
-
-protected:
-    void slotButtonClicked(int);
+    void slotOkClicked();
 public:
-    explicit NetworkDialog(bool client, QWidget* parent = 0, const KUrl* url = 0);
-    ~NetworkDialog();
+    explicit NetworkDialog(bool client, QWidget* parent = nullptr, const QUrl* url = nullptr);
+    ~NetworkDialog() override;
     
     QString nickname() const;
     QTcpSocket* socket() const;
-signals:
+Q_SIGNALS:
     void ok();
 };
 
