@@ -19,8 +19,8 @@ WelcomeScreen::WelcomeScreen(const QFont& font)
 : QObject()
 , QGraphicsRectItem()
 , m_font(font)
-, m_clicked(0)
-, m_hover(0)
+, m_clicked(nullptr)
+, m_hover(nullptr)
 , m_active(true)
 {
     QBrush brush(QColor(0, 0, 0, 80));
@@ -124,8 +124,8 @@ void WelcomeScreen::moveButton(int x1, int y1, int x2, int y2)
 
 void WelcomeScreen::clearButtons()
 {
-    m_clicked = 0;
-    m_hover = 0;
+    m_clicked = nullptr;
+    m_hover = nullptr;
     for (Buttons::const_iterator i = m_buttons.constBegin();
          i != m_buttons.constEnd();
          ++i) {
@@ -164,11 +164,11 @@ void WelcomeScreen::onMouseRelease(Button *button)
     if (m_clicked && m_clicked == button) {
         // actual click event
         if (m_clicked->onClicked()) {            
-            emit clicked(button);
+            Q_EMIT clicked(button);
         }
     }
     
-    m_clicked = 0;
+    m_clicked = nullptr;
 }
 
 void WelcomeScreen::fadeOut()
@@ -183,7 +183,7 @@ void WelcomeScreen::show()
     m_active = true;
     setOpacity(1);
     QGraphicsRectItem::show();
-    emit shown();
+    Q_EMIT shown();
 }
 
 void WelcomeScreen::hide()
@@ -191,7 +191,7 @@ void WelcomeScreen::hide()
     m_active = false;
     QGraphicsRectItem::hide();
     clearButtons();
-    emit hidden();
+    Q_EMIT hidden();
 }
 
 void WelcomeScreen::onMouseLeave()
